Package: googledrive
Title: An Interface to Google Drive
Version: 2.1.1
Authors@R: c(
    person("Lucy", "D'Agostino McGowan", , role = "aut"),
    person("Jennifer", "Bryan", , "jenny@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6983-2759")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Manage Google Drive files from R.
License: MIT + file LICENSE
URL: https://googledrive.tidyverse.org,
        https://github.com/tidyverse/googledrive
BugReports: https://github.com/tidyverse/googledrive/issues
Depends: R (>= 3.6)
Imports: cli (>= 3.0.0), gargle (>= 1.5.0), glue (>= 1.4.2), httr,
        jsonlite, lifecycle, magrittr, pillar (>= 1.9.0), purrr (>=
        1.0.1), rlang (>= 1.0.2), tibble (>= 2.0.0), utils, uuid, vctrs
        (>= 0.3.0), withr
Suggests: curl, dplyr (>= 1.0.0), knitr, mockr, rmarkdown, spelling,
        testthat (>= 3.1.3)
VignetteBuilder: knitr
Config/Needs/website: tidyverse, tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-06-11 05:34:24 UTC; jenny
Author: Lucy D'Agostino McGowan [aut],
  Jennifer Bryan [aut, cre] (<https://orcid.org/0000-0002-6983-2759>),
  Posit Software, PBC [cph, fnd]
Maintainer: Jennifer Bryan <jenny@posit.co>
Repository: CRAN
Date/Publication: 2023-06-11 19:30:08 UTC
Built: R 4.6.0; ; 2026-07-20 00:46:50 UTC; unix
