# Generated by roxygen2: do not edit by hand

S3method("[",dribble)
S3method("names<-",dribble)
S3method(as_dribble,"NULL")
S3method(as_dribble,character)
S3method(as_dribble,data.frame)
S3method(as_dribble,default)
S3method(as_dribble,drive_id)
S3method(as_dribble,list)
S3method(as_id,"NULL")
S3method(as_id,character)
S3method(as_id,data.frame)
S3method(as_id,default)
S3method(as_id,dribble)
S3method(as_id,drive_id)
S3method(as_shared_drive,"NULL")
S3method(as_shared_drive,character)
S3method(as_shared_drive,data.frame)
S3method(as_shared_drive,default)
S3method(as_shared_drive,dribble)
S3method(as_shared_drive,drive_id)
S3method(as_shared_drive,list)
S3method(as_tibble,dribble)
S3method(format,drive_user)
S3method(gargle_map_cli,dribble)
S3method(gargle_map_cli,drive_id)
S3method(pillar_shaft,drive_id)
S3method(print,drive_user)
S3method(tbl_sum,dribble)
S3method(vec_cast,character.drive_id)
S3method(vec_cast,data.frame.dribble)
S3method(vec_cast,dribble.data.frame)
S3method(vec_cast,dribble.dribble)
S3method(vec_cast,dribble.tbl_df)
S3method(vec_cast,drive_id.character)
S3method(vec_cast,drive_id.drive_id)
S3method(vec_cast,tbl_df.dribble)
S3method(vec_ptype2,character.drive_id)
S3method(vec_ptype2,data.frame.dribble)
S3method(vec_ptype2,dribble.data.frame)
S3method(vec_ptype2,dribble.dribble)
S3method(vec_ptype2,dribble.tbl_df)
S3method(vec_ptype2,drive_id.character)
S3method(vec_ptype2,drive_id.drive_id)
S3method(vec_ptype2,tbl_df.dribble)
S3method(vec_ptype_abbr,drive_id)
S3method(vec_restore,dribble)
export("%>%")
export(as_dribble)
export(as_id)
export(as_shared_drive)
export(as_team_drive)
export(confirm_dribble)
export(confirm_single_file)
export(confirm_some_files)
export(do_paginated_request)
export(do_request)
export(drive_about)
export(drive_api_key)
export(drive_auth)
export(drive_auth_config)
export(drive_auth_configure)
export(drive_browse)
export(drive_cp)
export(drive_create)
export(drive_deauth)
export(drive_download)
export(drive_empty_trash)
export(drive_endpoint)
export(drive_endpoints)
export(drive_example)
export(drive_example_local)
export(drive_example_remote)
export(drive_examples_local)
export(drive_examples_remote)
export(drive_extension)
export(drive_fields)
export(drive_find)
export(drive_get)
export(drive_has_token)
export(drive_link)
export(drive_ls)
export(drive_mime_type)
export(drive_mkdir)
export(drive_mv)
export(drive_oauth_app)
export(drive_oauth_client)
export(drive_publish)
export(drive_put)
export(drive_read_raw)
export(drive_read_string)
export(drive_rename)
export(drive_reveal)
export(drive_rm)
export(drive_scopes)
export(drive_share)
export(drive_share_anyone)
export(drive_token)
export(drive_trash)
export(drive_unpublish)
export(drive_untrash)
export(drive_update)
export(drive_upload)
export(drive_user)
export(expose)
export(is_dribble)
export(is_folder)
export(is_folder_shortcut)
export(is_mine)
export(is_native)
export(is_parental)
export(is_shared_drive)
export(is_shortcut)
export(is_team_drive)
export(local_drive_quiet)
export(no_file)
export(prep_fields)
export(request_generate)
export(request_make)
export(shared_drive_create)
export(shared_drive_find)
export(shared_drive_get)
export(shared_drive_rm)
export(shared_drive_update)
export(shortcut_create)
export(shortcut_resolve)
export(single_file)
export(some_files)
export(team_drive_create)
export(team_drive_find)
export(team_drive_get)
export(team_drive_rm)
export(team_drive_update)
export(with_drive_quiet)
import(rlang)
import(vctrs)
importFrom(gargle,bulletize)
importFrom(gargle,gargle_map_cli)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(glue,glue_data)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(pillar,pillar_shaft)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_chr)
importFrom(purrr,map_if)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,pluck)
importFrom(tibble,as_tibble)
importFrom(tibble,tbl_sum)
importFrom(tibble,tibble)
